pilas.asistente_base.Ui_AsistenteWindow

Package pilas :: Module asistente_base :: Class Ui_AsistenteWindow |
[hide private]
[frames] | no frames]

# Class Ui_AsistenteWindow

source code

    object --+
             |
            Ui_AsistenteWindow

Instance Methods | [hide private]
setupUi(self, AsistenteWindow) | source code
retranslateUi(self, AsistenteWindow) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`